@@ -39,19 +39,15 @@ mcmcParams)
                 p0 <- ncol(Xmat0) + ncol(Xmat.adj)
                 p1 <- ncol(Xmat1) + ncol(Xmat.adj)
                 p_adj <- ncol(Xmat.adj)
-                
-                Xmat0 <- cbind(Xmat0, Xmat.adj)
-                Xmat1 <- cbind(Xmat1, Xmat.adj)
-                
+
                 if(p_adj > 0){
-                    covNames.z = c(colnames(Xmat0), colnames(Xmat.adj))
-                    covNames.x = c(colnames(Xmat1), colnames(Xmat.adj))
-                }
-                if(p_adj == 0){
-                    covNames.z = colnames(Xmat0)
-                    covNames.x = colnames(Xmat1)
+                    Xmat0 <- cbind(Xmat0, Xmat.adj)
+                    Xmat1 <- cbind(Xmat1, Xmat.adj)
                 }
                 
+                covNames.z = c(colnames(Xmat0))
+                covNames.x = c(colnames(Xmat1))
+                
                 ###
                 gamma_beta <- temp$B
                 gamma_beta[gamma_beta !=0] <- 1
@@ -194,19 +190,15 @@ mcmcParams)
                 
                 p <- p1+p_adj
                 p0 <- p1 <- p
-                
-                Xmat0 <- cbind(Xmat0, Xmat.adj)
-                Xmat1 <- cbind(Xmat1, Xmat.adj)
-                
+
                 if(p_adj > 0){
-                    covNames.z = c(colnames(Xmat0), colnames(Xmat.adj))
-                    covNames.x = c(colnames(Xmat1), colnames(Xmat.adj))
-                }
-                if(p_adj == 0){
-                    covNames.z = colnames(Xmat0)
-                    covNames.x = colnames(Xmat1)
+                    Xmat0 <- cbind(Xmat0, Xmat.adj)
+                    Xmat1 <- cbind(Xmat1, Xmat.adj)
                 }
                 
+                covNames.z = c(colnames(Xmat0))
+                covNames.x = c(colnames(Xmat1))
+                
                 ###
                 gamma <- temp$B
                 gamma[gamma !=0] <- 1
@@ -335,18 +327,14 @@ mcmcParams)
             p <- p1+p_adj
             p0 <- p1 <- p
             
-            Xmat0 <- cbind(Xmat0, Xmat.adj)
-            Xmat1 <- cbind(Xmat1, Xmat.adj)
-            
             if(p_adj > 0){
-                covNames.z = c(colnames(Xmat0), colnames(Xmat.adj))
-                covNames.x = c(colnames(Xmat1), colnames(Xmat.adj))
-            }
-            if(p_adj == 0){
-                covNames.z = colnames(Xmat0)
-                covNames.x = colnames(Xmat1)
+                Xmat0 <- cbind(Xmat0, Xmat.adj)
+                Xmat1 <- cbind(Xmat1, Xmat.adj)
             }
             
+            covNames.z = c(colnames(Xmat0))
+            covNames.x = c(colnames(Xmat1))
+            
             ###
             gamma_beta <- temp$B
             gamma_beta[gamma_beta !=0] <- 1
